@@ -1,7 +1,7 @@
 #!/bin/sh
 ########################################################################
 #    
-#    (c) 2001-2006 Intersect Alliance Pty Ltd
+#    (c) 2001-2007 Intersect Alliance Pty Ltd
 # 
 #   This script will automate the installation of the snare audit daemon.
 #   
@@ -442,6 +442,14 @@ if [ $INSTALL_TYPE -eq 1 ] || [ $INSTALL_TYPE -eq 2 ] || [ $INSTALL_TYPE -eq 3 ]
 	     echo "Unable to copy the startup script: /etc/init.d/audit. Terminating script"
 	     exit 1
 	   fi
+	   cp ./snare_start.sh  /etc/init.d/snare
+	   RETVAL=$?
+	   if [ $RETVAL -gt 0 ]
+	   then
+	     echo "Unable to copy the startup script: /etc/init.d/snare. Terminating script"
+	     exit 1
+	   fi
+
    else
 	   cp ./snare.xml /var/svc/manifest/application/security/snare.xml
 	   RETVAL=$?
@@ -466,14 +474,15 @@ if [ $INSTALL_TYPE -eq 1 ] || [ $INSTALL_TYPE -eq 2 ] || [ $INSTALL_TYPE -eq 3 ]
 	     echo "Unable to import the SMF script: /var/svc/manifest/application/security/snare.xml. Terminating script"
 	     exit 1
 	   fi
-   fi
 
-   cp ./snare_start.sh  /etc/init.d/snare
-   RETVAL=$?
-   if [ $RETVAL -gt 0 ]
-   then
-     echo "Unable to copy the startup script: /etc/init.d/snare. Terminating script"
-     exit 1
+	   cp ./snare_start.sh /lib/svc/method/svc-snare
+	   RETVAL=$?
+	   if [ $RETVAL -gt 0 ]
+	   then
+	     echo "Unable to copy the startup script: /lib/svc/method/svc-snare. Terminating script"
+	     exit 1
+	   fi
+
    fi
 
    cp ./snare_audit_control /etc/security/audit_control
